@@ -1,14 +1,15 @@
 from django import forms
 from django.contrib import admin
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
 from ..forms.journals import JournalEntryAdminForm, JournalLeaderEntryAdminForm
-from ..models.journals import JournalLeaderEntry
+from ..models.journals import JournalEntry, JournalLeaderEntry
 from .export import AdminExportMixin
 from .filters import LeaderListFilter, SchoolYearListFilter, SubjectListFilter
 
 
+@admin.register(JournalLeaderEntry)
 class JournalLeaderEntryAdmin(AdminExportMixin, admin.ModelAdmin):
     form = JournalLeaderEntryAdminForm
     list_display = ('timesheet', 'date', 'start', 'end', 'duration', 'subject')
@@ -55,14 +56,15 @@ class JournalLeaderEntryInlineAdmin(admin.TabularInline):
 
     def edit_link(self, obj):
         return '<a href="{url}" title="{title}" target="_blank">{edit}</a>'.format(
-            url = reverse('admin:leprikon_journalleaderentry_change', args=[obj.id]),
-            title = _('update entry'),
-            edit = _('edit'),
+            url=reverse('admin:leprikon_journalleaderentry_change', args=[obj.id]),
+            title=_('update entry'),
+            edit=_('edit'),
         )
     edit_link.short_description = ''
     edit_link.allow_tags = True
 
 
+@admin.register(JournalEntry)
 class JournalEntryAdmin(AdminExportMixin, admin.ModelAdmin):
     form = JournalEntryAdminForm
     date_hierarchy = 'date'
@@ -71,7 +73,7 @@ class JournalEntryAdmin(AdminExportMixin, admin.ModelAdmin):
         ('subject__school_year', SchoolYearListFilter),
         ('subject', SubjectListFilter),
     )
-    filter_horizontal = ('registrations',)
+    filter_horizontal = ('participants',)
     inlines = (JournalLeaderEntryInlineAdmin,)
     ordering = ('-date', '-start')
     readonly_fields = ('subject_name', 'date',)
@@ -81,7 +83,7 @@ class JournalEntryAdmin(AdminExportMixin, admin.ModelAdmin):
 
     def has_delete_permission(self, request, obj=None):
         if obj:
-            if obj.leader_entries.filter(timesheet__submitted=True).exists():
+            if obj.affects_submitted_timesheets:
                 return False
             else:
                 return super(JournalEntryAdmin, self).has_delete_permission(request, obj)
