@@ -1,5 +1,4 @@
 from bankreader.models import Transaction as BankreaderTransaction
-from django import forms
 from django.conf.urls import url as urls_url
 from django.contrib import admin, messages
 from django.contrib.admin.templatetags.admin_list import _boolean_icon
@@ -18,6 +17,7 @@ from django.urls import reverse
 from django.utils.formats import date_format
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
+from django.utils.timezone import localtime
 from django.utils.translation import ugettext_lazy as _
 
 from ..forms.subjects import (
@@ -35,6 +35,7 @@ from ..models.utils import (
     lazy_help_text_with_default, lazy_help_text_with_html_default,
 )
 from ..utils import amount_color, currency
+from .bulkupdate import BulkUpdateMixin
 from .export import AdminExportMixin
 from .filters import (
     ApprovedListFilter, CanceledListFilter, IsNullFieldListFilter,
@@ -57,7 +58,11 @@ class SubjectTypeAttachmentInlineAdmin(admin.TabularInline):
 
 
 @admin.register(SubjectType)
-class SubjectTypeAdmin(admin.ModelAdmin):
+class SubjectTypeAdmin(BulkUpdateMixin, admin.ModelAdmin):
+    bulk_update_exclude = (
+        'subject_type', 'slug', 'order', 'name',
+        'plural', 'name_genitiv', 'name_akuzativ',
+    )
     list_display = ('plural', 'order')
     list_editable = ('order',)
     exclude = ('order',)
@@ -95,7 +100,7 @@ class SubjectVariantInlineAdmin(admin.TabularInline):
     extra = 0
 
 
-class SubjectBaseAdmin(AdminExportMixin, SendMessageAdminMixin, admin.ModelAdmin):
+class SubjectBaseAdmin(AdminExportMixin, BulkUpdateMixin, SendMessageAdminMixin, admin.ModelAdmin):
     registration_model = None
     list_editable = ('public', 'note')
     list_filter = (
@@ -300,32 +305,6 @@ class SubjectBaseAdmin(AdminExportMixin, SendMessageAdminMixin, admin.ModelAdmin
     icon.allow_tags = True
     icon.short_description = _('photo')
 
-    def set_registration_dates(self, request, queryset):
-        class RegistrationDatesForm(forms.Form):
-            reg_from = self.formfield_for_dbfield(Subject._meta.get_field('reg_from'), request=request)
-            reg_to = self.formfield_for_dbfield(Subject._meta.get_field('reg_to'), request=request)
-        if request.POST.get('post', 'no') == 'yes':
-            form = RegistrationDatesForm(request.POST)
-            if form.is_valid():
-                Subject.objects.filter(id__in=[s['id'] for s in queryset.values('id')]).update(
-                    reg_from=form.cleaned_data['reg_from'],
-                    reg_to=form.cleaned_data['reg_to'],
-                )
-                self.message_user(request, _('Registration dates were updated.'))
-                return
-        else:
-            form = RegistrationDatesForm()
-        return render(request, 'leprikon/admin/change_form.html', {
-            'title': _('Select registration dates'),
-            'queryset': queryset,
-            'opts': self.model._meta,
-            'form': form,
-            'media': self.media + form.media,
-            'action': 'set_registration_dates',
-            'action_checkbox_name': admin.helpers.ACTION_CHECKBOX_NAME,
-        })
-    set_registration_dates.short_description = _('Set registration dates')
-
 
 class ChangeformRedirectMixin:
     def changeform_view(self, request, object_id=None, form_url='', extra_context=None):
@@ -670,36 +649,36 @@ class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMessageAdminMixin, admi
         return obj.subject.name
     subject_name.short_description = _('subject')
 
-    def _date_with_by(self, obj, attr):
+    def _datetime_with_by(self, obj, attr):
         d = getattr(obj, attr)
         if d:
-            d_formated = date_format(d, 'SHORT_DATETIME_FORMAT')
+            d_formated = date_format(localtime(d), 'SHORT_DATETIME_FORMAT')
             by = getattr(obj, attr + '_by')
             return mark_safe(f'<span title="{by}">{d_formated}</span>') if by else d_formated
         return '-'
 
     def created_with_by(self, obj):
-        return self._date_with_by(obj, 'created')
+        return self._datetime_with_by(obj, 'created')
     created_with_by.admin_order_field = 'created'
     created_with_by.short_description = _('time of registration')
 
     def approved_with_by(self, obj):
-        return self._date_with_by(obj, 'approved')
+        return self._datetime_with_by(obj, 'approved')
     approved_with_by.admin_order_field = 'approved'
     approved_with_by.short_description = _('time of approval')
 
     def payment_requested_with_by(self, obj):
-        return self._date_with_by(obj, 'payment_requested')
+        return self._datetime_with_by(obj, 'payment_requested')
     payment_requested_with_by.admin_order_field = 'payment_requested'
     payment_requested_with_by.short_description = _('payment request time')
 
     def cancelation_requested_with_by(self, obj):
-        return self._date_with_by(obj, 'cancelation_requested')
+        return self._datetime_with_by(obj, 'cancelation_requested')
     cancelation_requested_with_by.admin_order_field = 'cancelation_requested'
     cancelation_requested_with_by.short_description = _('time of cancellation request')
 
     def canceled_with_by(self, obj):
-        return self._date_with_by(obj, 'canceled')
+        return self._datetime_with_by(obj, 'canceled')
     canceled_with_by.admin_order_field = 'canceled'
     canceled_with_by.short_description = _('time of cancellation')
 
