@@ -1,9 +1,10 @@
 from cms.menu_bases import CMSAttachMenu
-from django.core.urlresolvers import NoReverseMatch, reverse
 from django.db.models.signals import post_delete, post_save
+from django.urls import NoReverseMatch, reverse
 from django.utils.translation import ugettext_lazy as _
-from menus.base import Modifier, NavigationNode
+from menus.base import Menu, Modifier, NavigationNode
 from menus.menu_pool import menu_pool
+from social_django.context_processors import backends
 
 from .models.subjects import SubjectType
 from .utils import current_url, first_upper, url_with_back
@@ -19,24 +20,6 @@ class LeprikonMenu(CMSAttachMenu):
         """
         try:
             nodes = []
-            nodes.append(NavigationNode(
-                _('Log in'),
-                reverse('leprikon:user_login'),
-                len(nodes),
-                attr={'visible_for_authenticated': False, 'add_url_back': True},
-            ))
-            nodes.append(NavigationNode(
-                _('Create account'),
-                reverse('leprikon:user_create'),
-                len(nodes),
-                attr={'visible_for_authenticated': False},
-            ))
-            nodes.append(NavigationNode(
-                _('Reset password'),
-                reverse('leprikon:password_reset'),
-                len(nodes),
-                attr={'visible_for_authenticated': False},
-            ))
             nodes.append(NavigationNode(
                 _('Summary'),
                 reverse('leprikon:summary'),
@@ -49,7 +32,6 @@ class LeprikonMenu(CMSAttachMenu):
                 len(nodes),
                 attr={'require_staff': True},
             ))
-            leader = len(nodes)
             nodes.append(NavigationNode(
                 _('Leader'),
                 reverse('leprikon:leader_summary'),
@@ -61,31 +43,20 @@ class LeprikonMenu(CMSAttachMenu):
                     first_upper(_('My {subject_type}').format(subject_type=subject_type.plural)),
                     reverse('leprikon:subject_list_mine', kwargs={'subject_type': subject_type.slug}),
                     len(nodes),
-                    parent_id=leader,
                     attr={'require_leader': True},
                 ))
             nodes.append(NavigationNode(
                 _('Alternating'),
                 reverse('leprikon:alternating'),
                 len(nodes),
-                parent_id=leader,
                 attr={'require_leader': True},
             ))
-            timesheets = len(nodes)
             nodes.append(NavigationNode(
                 _('Timesheets'),
                 reverse('leprikon:timesheet_list'),
                 len(nodes),
-                parent_id=leader,
                 attr={'require_leader': True},
             ))
-            nodes.append(NavigationNode(
-                _('Add new entry'),
-                reverse('leprikon:timesheetentry_create'),
-                len(nodes),
-                parent_id=timesheets,
-                attr={'require_leader': True, 'add_url_back': True},
-            ))
             nodes.append(NavigationNode(
                 _('Messages'),
                 reverse('leprikon:message_list'),
@@ -104,7 +75,6 @@ class LeprikonMenu(CMSAttachMenu):
                 len(nodes),
                 attr={'visible_for_anonymous': False},
             ))
-            participants = len(nodes)
             nodes.append(NavigationNode(
                 _('Participants'),
                 reverse('leprikon:participant_list'),
@@ -112,38 +82,8 @@ class LeprikonMenu(CMSAttachMenu):
                 attr={'visible_for_anonymous': False},
             ))
             nodes.append(NavigationNode(
-                _('Add participant'),
-                reverse('leprikon:participant_create'),
-                len(nodes),
-                parent_id=participants,
-                attr={'visible_for_anonymous': False, 'add_url_back': True},
-            ))
-            nodes.append(NavigationNode(
-                _('Add parent'),
-                reverse('leprikon:parent_create'),
-                len(nodes),
-                parent_id=participants,
-                attr={'visible_for_anonymous': False, 'add_url_back': True},
-            ))
-            for subject_type in SubjectType.objects.all():
-                nodes.append(NavigationNode(
-                    first_upper(subject_type.plural),
-                    reverse('leprikon:subject_list', kwargs={'subject_type': subject_type.slug}),
-                    len(nodes),
-                ))
-            nodes.append(NavigationNode(
-                _('Leaders'),
-                reverse('leprikon:leader_list'),
-                len(nodes),
-            ))
-            nodes.append(NavigationNode(
-                _('Terms and Conditions'),
-                reverse('leprikon:terms_conditions'),
-                len(nodes),
-            ))
-            nodes.append(NavigationNode(
-                _('Log out'),
-                reverse('leprikon:user_logout'),
+                _('Billing information'),
+                reverse('leprikon:billing_info_list'),
                 len(nodes),
                 attr={'visible_for_anonymous': False},
             ))
@@ -152,31 +92,117 @@ class LeprikonMenu(CMSAttachMenu):
             return []
 
 
+@menu_pool.register_menu
+class UserMenu(Menu):
+    def get_nodes(self, request):
+        """
+        This method is used to build the menu tree.
+        """
+        nodes = []
+
+        # anonymous user
+        nodes.append(NavigationNode(
+            _('Log in'),
+            reverse('leprikon:user_login'),
+            len(nodes),
+            attr={'visible_for_authenticated': False, 'add_url_back': True},
+        ))
+        nodes.append(NavigationNode(
+            _('Create account'),
+            reverse('leprikon:user_create'),
+            len(nodes),
+            attr={'visible_for_authenticated': False, 'add_url_back': True},
+        ))
+        nodes.append(NavigationNode(
+            _('Reset password'),
+            reverse('leprikon:password_reset'),
+            len(nodes),
+            attr={'visible_for_authenticated': False, 'add_url_back': True},
+        ))
+
+        # user settings
+        nodes.append(NavigationNode(
+            _('Change user details'),
+            reverse('leprikon:user_update'),
+            len(nodes),
+            attr={'visible_for_anonymous': False, 'add_url_back': True},
+        ))
+        nodes.append(NavigationNode(
+            _('Change e-mail'),
+            reverse('leprikon:user_email'),
+            len(nodes),
+            attr={'visible_for_anonymous': False, 'add_url_back': True},
+        ))
+        nodes.append(NavigationNode(
+            _('Change password'),
+            reverse('leprikon:user_password'),
+            len(nodes),
+            attr={'visible_for_anonymous': False, 'add_url_back': True},
+        ))
+        nodes.append(NavigationNode(
+            _('Link with Google account'),
+            reverse('social:begin', args=('google-oauth2',)),
+            len(nodes),
+            attr={'visible_for_anonymous': False, 'add_url_back': True,
+                  'social_backend': 'google-oauth2', 'social_btn': 'google'},
+        ))
+        nodes.append(NavigationNode(
+            _('Link with Facebook account'),
+            reverse('social:begin', args=('facebook',)),
+            len(nodes),
+            attr={'visible_for_anonymous': False, 'add_url_back': True,
+                  'social_backend': 'facebook', 'social_btn': 'facebook'},
+        ))
+        nodes.append(NavigationNode(
+            _('Log out'),
+            reverse('leprikon:user_logout'),
+            len(nodes),
+            attr={'visible_for_anonymous': False},
+        ))
+        return nodes
+
+
 @menu_pool.register_modifier
 class LeprikonModifier(Modifier):
     def modify(self, request, nodes, namespace, root_id, post_cut, breadcrumb):
         if post_cut or breadcrumb:
             return nodes
         final = []
+        backends_not_associated = backends(request)['backends']['not_associated']
         for node in nodes:
-            if (
-                (node.attr.get('require_leader', False) and not request.leader) or
-                (node.attr.get('require_staff', False) and not request.user.is_staff)
-            ):
-                if node.parent and node in node.parent.children:
-                    node.parent.children.remove(node)
-                continue
-            else:
+            show = True
+            if node.attr.get('require_leader', False):
+                if not request.leader or not request.leader.school_years.filter(id=request.school_year.id).exists():
+                    show = False
+            if node.attr.get('require_staff', False) and not request.user.is_staff:
+                show = False
+            if node.attr.get('social_backend') and (node.attr.get('social_backend') not in backends_not_associated):
+                show = False
+            if show:
                 if node.attr.get('add_url_back', False):
                     node.url = url_with_back(node.url, current_url(request))
                 final.append(node)
+            else:
+                if node.parent and node in node.parent.children:
+                    node.parent.children.remove(node)
+                continue
         return final
 
 
+@menu_pool.register_modifier
+class NamespaceModifier(Modifier):
+    def modify(self, request, nodes, namespace, root_id, post_cut, breadcrumb):
+        if namespace and not (post_cut or breadcrumb):
+            namespaces = namespace.split(',')
+            return [node for node in nodes if node.namespace.split(':')[0] in namespaces]
+        else:
+            return nodes
+
+
 # clear menu cache with each reload
 try:
     menu_pool.clear()
-except:
+except Exception:
     # menu_pool.clear() uses database,
     # but this code may be executed
     # before the database is created
