@@ -24,12 +24,8 @@ from .models.subjects import CHAT_GROUP_BROADCAST, Subject, SubjectRegistration
 
 User = get_user_model()
 
-SERVER_EMAIL = re.search('[^<]+@[^>]+', settings.SERVER_EMAIL).group()
-
-
 http_re = re.compile('^http')
 
-
 Leprikon = {'_id': 'leprikon', 'username': settings.LEPRIKON_CHAT_USERNAME}
 
 
@@ -97,9 +93,9 @@ def get_rc_config():
         ('Accounts_iframe_url', reverse('leprikon:user_login')),
         ('Accounts_Iframe_api_method', 'GET'),
         ('Accounts_Iframe_api_url', reverse('leprikon:api:rocketchat')),
-        ('From_Email', SERVER_EMAIL),
+        ('From_Email', settings.SERVER_EMAIL_PLAIN),
         ('Organization_Name', ls.name),
-        ('Organization_Email', SERVER_EMAIL),
+        ('Organization_Email', settings.SERVER_EMAIL_PLAIN),
         ('Organization_Type', 'nonprofit'),
         ('Country', 'czechRepublic'),
         ('Industry', 'education'),
@@ -177,7 +173,7 @@ def get_rc_leprikon_data():
         'name': settings.LEPRIKON_CHAT_NAME,
         'username': settings.LEPRIKON_CHAT_USERNAME,
         'emails': [{
-            'address': SERVER_EMAIL,
+            'address': settings.SERVER_EMAIL_PLAIN,
             'verified': True,
         }],
         'active': True,
@@ -265,8 +261,8 @@ def get_rc_subscription_data(room_data, user, alert, groupMentions, owner_ids=No
 
 def get_rc_subject_subscriptions_data(room_data, subject):
     leader_users = {
-        l.user.id: l.user
-        for l in subject.leaders.select_related('user')
+        lu.user.id: lu.user
+        for lu in subject.leaders.select_related('user')
     }
     return chain(
         get_rc_subscription_data(room_data, user, False, 0, leader_users)
@@ -476,15 +472,11 @@ class RocketChat:
             for subscription in self._mongo.rocketchat_subscription.find({
                 'u._id': source_id
             }, session=self._mongo_session):
-                self._mongo.rocketchat_subscription.count_documents({
-                    'u._id': target_id,
-                    'rid': subscription['rid'],
-                }) or self._sync_one(
+                subscription['_id'] = f'''{subscription['rid']}-{target_u['_id']}'''
+                subscription['u'] = target_u
+                self._sync_one(
                     'rocketchat_subscription',
-                    {
-                        '_id': subscription['_id'],
-                        'u': target_u,
-                    },
+                    subscription,
                 )
             # merge transfer messages and rooms
             for collection in (
